;; Generated package description from expreg.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "expreg" "1.4.1" "Simple expand region" '((emacs "29.1")) :commit "b1dc64aef8ed8498a6d21e5e78ce7e0bda8407e0" :authors '(("Yuan Fu" . "casouri@gmail.com")) :maintainer '("Yuan Fu" . "casouri@gmail.com") :keywords '("text" "editing") :url "https://github.com/casouri/expreg")
